@@ -64,7 +64,7 @@ Fey::Role::SQL::HasLimitClause - A role for queries which can include a LIMIT cl
 
 =head1 SYNOPSIS
 
-  use MooseX::StrictConstructor;
+  use Moose;
 
   with 'Fey::Role::SQL::HasLimitClause';
 
