@@ -7,6 +7,8 @@ use Moose;
 
 with 'Fey::Role::SetOperation' => { keyword => 'UNION' };
 
+with 'Fey::Role::SQL::Cloneable';
+
 no Moose;
 
 1;
@@ -42,7 +44,13 @@ See L<Fey::Role::SetOperation> for all methods.
 
 =head1 ROLES
 
-This class does C<Fey::Role::SetOperation>.
+=over 4
+
+=item * L<Fey::Role::SetOperation>
+
+=item * L<Fey::Role::SQL::Cloneable>
+
+=back
 
 =head1 AUTHOR
 
@@ -54,7 +62,7 @@ See L<Fey> for details on how to report bugs.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
+Copyright 2009 Dave Rolsky, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
